aboutsummaryrefslogtreecommitdiffstats
path: root/python_openapi_client/fatcat_openapi_client/models/fileset_file.py
diff options
context:
space:
mode:
Diffstat (limited to 'python_openapi_client/fatcat_openapi_client/models/fileset_file.py')
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/fileset_file.py33
1 files changed, 17 insertions, 16 deletions
diff --git a/python_openapi_client/fatcat_openapi_client/models/fileset_file.py b/python_openapi_client/fatcat_openapi_client/models/fileset_file.py
index 9da23aad..15afd2f1 100644
--- a/python_openapi_client/fatcat_openapi_client/models/fileset_file.py
+++ b/python_openapi_client/fatcat_openapi_client/models/fileset_file.py
@@ -5,9 +5,9 @@
Fatcat is a scalable, versioned, API-oriented catalog of bibliographic entities and file metadata. # noqa: E501
- OpenAPI spec version: 0.3.1
+ The version of the OpenAPI document: 0.3.1
Contact: webservices@archive.org
- Generated by: https://github.com/swagger-api/swagger-codegen.git
+ Generated by: https://openapi-generator.tech
"""
@@ -18,25 +18,26 @@ import six
class FilesetFile(object):
- """NOTE: This class is auto generated by the swagger code generator program.
+ """NOTE: This class is auto generated by OpenAPI Generator.
+ Ref: https://openapi-generator.tech
Do not edit the class manually.
"""
"""
Attributes:
swagger_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name
and the value is json key in definition.
"""
- swagger_types = {
+ openapi_types = {
'path': 'str',
'size': 'int',
'md5': 'str',
'sha1': 'str',
'sha256': 'str',
- 'extra': 'object'
+ 'extra': 'dict(str, object)'
}
attribute_map = {
@@ -49,7 +50,7 @@ class FilesetFile(object):
}
def __init__(self, path=None, size=None, md5=None, sha1=None, sha256=None, extra=None): # noqa: E501
- """FilesetFile - a model defined in Swagger""" # noqa: E501
+ """FilesetFile - a model defined in OpenAPI""" # noqa: E501
self._path = None
self._size = None
@@ -144,8 +145,8 @@ class FilesetFile(object):
raise ValueError("Invalid value for `md5`, length must be less than or equal to `32`") # noqa: E501
if md5 is not None and len(md5) < 32:
raise ValueError("Invalid value for `md5`, length must be greater than or equal to `32`") # noqa: E501
- if md5 is not None and not re.search('[a-f0-9]{32}', md5): # noqa: E501
- raise ValueError("Invalid value for `md5`, must be a follow pattern or equal to `/[a-f0-9]{32}/`") # noqa: E501
+ if md5 is not None and not re.search(r'[a-f0-9]{32}', md5): # noqa: E501
+ raise ValueError(r"Invalid value for `md5`, must be a follow pattern or equal to `/[a-f0-9]{32}/`") # noqa: E501
self._md5 = md5
@@ -173,8 +174,8 @@ class FilesetFile(object):
raise ValueError("Invalid value for `sha1`, length must be less than or equal to `40`") # noqa: E501
if sha1 is not None and len(sha1) < 40:
raise ValueError("Invalid value for `sha1`, length must be greater than or equal to `40`") # noqa: E501
- if sha1 is not None and not re.search('[a-f0-9]{40}', sha1): # noqa: E501
- raise ValueError("Invalid value for `sha1`, must be a follow pattern or equal to `/[a-f0-9]{40}/`") # noqa: E501
+ if sha1 is not None and not re.search(r'[a-f0-9]{40}', sha1): # noqa: E501
+ raise ValueError(r"Invalid value for `sha1`, must be a follow pattern or equal to `/[a-f0-9]{40}/`") # noqa: E501
self._sha1 = sha1
@@ -202,8 +203,8 @@ class FilesetFile(object):
raise ValueError("Invalid value for `sha256`, length must be less than or equal to `64`") # noqa: E501
if sha256 is not None and len(sha256) < 64:
raise ValueError("Invalid value for `sha256`, length must be greater than or equal to `64`") # noqa: E501
- if sha256 is not None and not re.search('[a-f0-9]{64}', sha256): # noqa: E501
- raise ValueError("Invalid value for `sha256`, must be a follow pattern or equal to `/[a-f0-9]{64}/`") # noqa: E501
+ if sha256 is not None and not re.search(r'[a-f0-9]{64}', sha256): # noqa: E501
+ raise ValueError(r"Invalid value for `sha256`, must be a follow pattern or equal to `/[a-f0-9]{64}/`") # noqa: E501
self._sha256 = sha256
@@ -214,7 +215,7 @@ class FilesetFile(object):
Free-form additional metadata about this specific file in the set. Eg, `mimetype`. See guide for nomative (but unenforced) schema fields. # noqa: E501
:return: The extra of this FilesetFile. # noqa: E501
- :rtype: object
+ :rtype: dict(str, object)
"""
return self._extra
@@ -225,7 +226,7 @@ class FilesetFile(object):
Free-form additional metadata about this specific file in the set. Eg, `mimetype`. See guide for nomative (but unenforced) schema fields. # noqa: E501
:param extra: The extra of this FilesetFile. # noqa: E501
- :type: object
+ :type: dict(str, object)
"""
self._extra = extra
@@ -234,7 +235,7 @@ class FilesetFile(object):
"""Returns the model properties as a dict"""
result = {}
- for attr, _ in six.iteritems(self.swagger_types):
+ for attr, _ in six.iteritems(self.openapi_types):
value = getattr(self, attr)
if isinstance(value, list):
result[attr] = list(map(
@@ -18,25 +18,26 @@ import six
"""
Attributes:
- swagger_types (dict): The key is attribute name
+ openapi_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name